@@ -40,7 +40,6 @@ class AWSProvider(Provider):
         self.dsp_name = "AWS"
         self.ami_ids: typing.List[str] = []
         self.ssh_key = None
-        self.sec_group = None
         self.instance_tags = None
         self.max_retry = 1  # for retry strategy
         self.status_map = {
@@ -61,7 +60,6 @@ class AWSProvider(Provider):
         self,
         ami_ids,
         ssh_key,
-        sec_group,
         instance_tags,
         strategy=STRATEGY_ABORT,
         max_retry=1,
@@ -86,7 +84,6 @@ class AWSProvider(Provider):
 
         self.ami_ids = ami_ids
         self.ssh_key = ssh_key
-        self.sec_group = sec_group
         self.instance_tags = instance_tags
         login_end = datetime.now()
         login_duration = login_end - login_start
@@ -94,7 +91,7 @@ class AWSProvider(Provider):
 
     async def prepare_provisioning(self, reqs):
         """Prepare provisioning."""
-        pass
+        return bool(reqs)
 
     async def validate_hosts(self, reqs):
         """Validate that host requirements are well specified."""
@@ -163,7 +160,8 @@ class AWSProvider(Provider):
                 MaxCount=1,
                 InstanceType=specs.get("flavor"),
                 KeyName=self.ssh_key,
-                SecurityGroupIds=[self.sec_group],
+                SecurityGroupIds=specs.get("security_group_ids", []),
+                SubnetId=specs.get("subnet_id"),
             )
         except ClientError as creation_error:
             err_msg = (
@@ -189,6 +187,15 @@ class AWSProvider(Provider):
         # returns id of provisioned instance and required host name
         return (ids[0], req)
 
+    def get_ip_addresses(self, prov_result):
+        """Get IP address from a provisioning result."""
+        addresess = []
+        if prov_result.get("PublicIpAddress"):
+            addresess.append(prov_result.get("PublicIpAddress"))
+        if prov_result.get("PrivateIpAddress"):
+            addresess.append(prov_result.get("PrivateIpAddress"))
+        return addresess
+
     def prov_result_to_host_data(self, prov_result, req):
         """Transform provisioning result to needed host data."""
         # init the dict
@@ -199,7 +206,7 @@ class AWSProvider(Provider):
             if tag["Key"] == "name":
                 result["name"] = tag["Value"]  # should be one key "name"
 
-        result["addresses"] = [prov_result.get("PublicIpAddress")]
+        result["addresses"] = self.get_ip_addresses(prov_result)
         result["status"] = prov_result["State"]["Name"]
         result["os"] = prov_result.get("mrack_req").get("os")
         result["group"] = prov_result.get("mrack_req").get("group")
