@@ -15,9 +15,11 @@
 """Beaker transformer module."""
 import re
 
+from mrack.providers.provider import STRATEGY_ABORT
 from mrack.transformers.transformer import Transformer
 
 CONFIG_KEY = "beaker"
+DEFAULT_ATTEMPTS = 2
 
 
 class BeakerTransformer(Transformer):
@@ -28,7 +30,7 @@ class BeakerTransformer(Transformer):
         "distros",
         "pubkey",
         "reserve_duration",
-        "max_attempts",
+        "timeout",
     ]  # List[str]
 
     async def init_provider(self):
@@ -36,9 +38,11 @@ class BeakerTransformer(Transformer):
         self.dsp_name = "Beaker"
         await self._provider.init(
             distros=self.config["distros"].values(),
-            max_attempts=self.config["max_attempts"],
+            timeout=self.config["timeout"],
             reserve_duration=self.config["reserve_duration"],
             pubkey=self.config["pubkey"],
+            strategy=self.config.get("strategy", STRATEGY_ABORT),
+            max_retry=self.config.get("max_retry", DEFAULT_ATTEMPTS),
         )
 
     def _get_bkr_variant(self, host):
@@ -59,7 +63,10 @@ class BeakerTransformer(Transformer):
         return {
             "name": host["name"],
             "distro": required_distro,
+            "os": host["os"],
+            "group": host["group"],
             "meta_distro": "distro" in host,
             "arch": host.get("arch", "x86_64"),
             "variant": self._get_bkr_variant(host),
+            f"mrack_{CONFIG_KEY}": host.get(CONFIG_KEY, {}),
         }
