@@ -14,7 +14,8 @@
 
 """Podman transformer module."""
 
-from mrack.transformers.transformer import Transformer
+from mrack.providers.provider import STRATEGY_ABORT
+from mrack.transformers.transformer import DEFAULT_ATTEMPTS, Transformer
 from mrack.utils import get_host_from_metadata
 
 CONFIG_KEY = "podman"
@@ -40,6 +41,9 @@ class PodmanTransformer(Transformer):
             ssh_key=self.config["pubkey"],
             default_network=self.config["default_network"],
             container_options=self.config["podman_options"],
+            extra_commands=self.config.get("extra_commands", []),
+            strategy=self.config.get("strategy", STRATEGY_ABORT),
+            max_retry=self.config.get("max_retry", DEFAULT_ATTEMPTS),
         )
 
     def create_host_requirement(self, host):
@@ -48,6 +52,8 @@ class PodmanTransformer(Transformer):
         return {
             "name": host["name"],
             "image": self._get_image(host["os"]),
+            "os": host["os"],
+            "group": host["group"],
             "hostname": host["name"],
             "domain": domain["name"],
         }
